@@ -1,6 +1,6 @@
 from .jquery import *
 from .data_table import *
-from .misc_func import *
+from .lab_ext import *
 from .selectize import *
 from .tippy import *
 
